@@ -7,8 +7,14 @@
 
 """Marshmallow fields."""
 
+from .contrib import Function, Method
+from .edtfdatestring import EDTFDateString
 from .generated import GenFunction, GenMethod
 from .isodate import ISODateString
+from .isolanguage import ISOLangString
+from .links import Link, Links
+from .localized_edtfdatestring import LocalizedEDTFDateString
+from .nestedattr import NestedAttribute
 from .sanitizedhtml import ALLOWED_HTML_ATTRS, ALLOWED_HTML_TAGS, SanitizedHTML
 from .sanitizedunicode import SanitizedUnicode
 from .trimmed import TrimmedString
@@ -16,9 +22,17 @@ from .trimmed import TrimmedString
 __all__ = (
     'ALLOWED_HTML_ATTRS',
     'ALLOWED_HTML_TAGS',
+    'EDTFDateString',
+    'Function',
+    'LocalizedEDTFDateString',
     'GenFunction',
     'GenMethod',
     'ISODateString',
+    'ISOLangString',
+    'Link',
+    'Links',
+    'Method',
+    'NestedAttribute',
     'SanitizedHTML',
     'SanitizedUnicode',
     'TrimmedString',
